import{e as d,f as o,g as i,q as n,w as r,p as s,l as c,k as l,aM as f}from"./jwt-decode.esm-C7p7KYmD.js";import{R as _}from"./index-DaSKhJTc.js";import{C as u}from"./index-Bq1tJAxg.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="e7e64b10-ae4f-49c3-a92b-551527aadafe",e._sentryDebugIdIdentifier="sentry-dbid-e7e64b10-ae4f-49c3-a92b-551527aadafe")}catch{}})();const p={class:"credentials-page"},b=d({__name:"CredentialsSuccessView",setup(e){return(a,t)=>(i(),o("div",p,[n(s(u),{class:"credentials-card"},{default:r(()=>[n(s(_),{title:s(c).translate("i18n_credential_form_thank_you")},{icon:r(()=>[...t[0]||(t[0]=[l("span",null,null,-1)])]),_:1},8,["title"])]),_:1})]))}}),g=f(b,[["__scopeId","data-v-f9bd641e"]]);export{g as default};
//# sourceMappingURL=CredentialsSuccessView-Bvm7vgIL.js.map
