import{e as i,b as n,f as d,g as u,E as o,F as r,k as c,h as f}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3fb99031-47c6-4206-a460-e5c599f891bb",e._sentryDebugIdIdentifier="sentry-dbid-3fb99031-47c6-4206-a460-e5c599f891bb")}catch{}})();const p=i({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,s=n(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),a=n(()=>({position:"absolute",inset:0,overflow:"auto",...t.innerStyle??{}}));return(l,y)=>(u(),d("div",{style:r(s.value),class:o(e.outerClass)},[c("div",{style:r(a.value),class:o(e.innerClass)},[f(l.$slots,"default")],6)],6))}});export{p as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang-BfIBHUU6.js.map
