import{e as d,b as s,f as l,g as f,k as i,h as r,F as u,E as a,aM as c}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="91f3480f-6f19-4836-884d-1e9ab6f15d12",e._sentryDebugIdIdentifier="sentry-dbid-91f3480f-6f19-4836-884d-1e9ab6f15d12")}catch{}})();const y=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(o,g)=>(f(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[i("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:u(t.value)},[r(o.$slots,"default",{},void 0,!0)],6)],2))}}),b=c(y,[["__scopeId","data-v-00e066e8"]]);export{b as C};
//# sourceMappingURL=ContentLayout-CjSx9x5N.js.map
