(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="bfd16f4c-b810-417a-9fab-3fa5f6d1f75b",e._sentryDebugIdIdentifier="sentry-dbid-bfd16f4c-b810-417a-9fab-3fa5f6d1f75b")}catch{}})();function a(e){return new RegExp("^(("+e.join(")|(")+"))\\b")}var f=["Clamp","Constructor","EnforceRange","Exposed","ImplicitThis","Global","PrimaryGlobal","LegacyArrayClass","LegacyUnenumerableNamedProperties","LenientThis","NamedConstructor","NewObject","NoInterfaceObject","OverrideBuiltins","PutForwards","Replaceable","SameObject","TreatNonObjectAsNull","TreatNullAs","EmptyString","Unforgeable","Unscopeable"],u=a(f),o=["unsigned","short","long","unrestricted","float","double","boolean","byte","octet","Promise","ArrayBuffer","DataView","Int8Array","Int16Array","Int32Array","Uint8Array","Uint16Array","Uint32Array","Uint8ClampedArray","Float32Array","Float64Array","ByteString","DOMString","USVString","sequence","object","RegExp","Error","DOMException","FrozenArray","any","void"],d=a(o),l=["attribute","callback","const","deleter","dictionary","enum","getter","implements","inherit","interface","iterable","legacycaller","maplike","partial","required","serializer","setlike","setter","static","stringifier","typedef","optional","readonly","or"],s=a(l),c=["true","false","Infinity","NaN","null"],y=a(c),m=["callback","dictionary","enum","interface"],b=a(m),p=["typedef"],v=a(p),g=/^[:<=>?]/,A=/^-?([1-9][0-9]*|0[Xx][0-9A-Fa-f]+|0[0-7]*)/,h=/^-?(([0-9]+\.[0-9]*|[0-9]*\.[0-9]+)([Ee][+-]?[0-9]+)?|[0-9]+[Ee][+-]?[0-9]+)/,i=/^_?[A-Za-z][0-9A-Z_a-z-]*/,D=/^_?[A-Za-z][0-9A-Z_a-z-]*(?=\s*;)/,w=/^"[^"]*"/,k=/^\/\*.*?\*\//,E=/^\/\*.*/,C=/^.*?\*\//;function I(e,r){if(e.eatSpace())return null;if(r.inComment)return e.match(C)?(r.inComment=!1,"comment"):(e.skipToEnd(),"comment");if(e.match("//"))return e.skipToEnd(),"comment";if(e.match(k))return"comment";if(e.match(E))return r.inComment=!0,"comment";if(e.match(/^-?[0-9\.]/,!1)&&(e.match(A)||e.match(h)))return"number";if(e.match(w))return"string";if(r.startDef&&e.match(i))return"def";if(r.endDef&&e.match(D))return r.endDef=!1,"def";if(e.match(s))return"keyword";if(e.match(d)){var t=r.lastToken,n=(e.match(/^\s*(.+?)\b/,!1)||[])[1];return t===":"||t==="implements"||n==="implements"||n==="="?"builtin":"type"}return e.match(u)?"builtin":e.match(y)?"atom":e.match(i)?"variable":e.match(g)?"operator":(e.next(),null)}const N={name:"webidl",startState:function(){return{inComment:!1,lastToken:"",startDef:!1,endDef:!1}},token:function(e,r){var t=I(e,r);if(t){var n=e.current();r.lastToken=n,t==="keyword"?(r.startDef=b.test(n),r.endDef=r.endDef||v.test(n)):r.startDef=!1}return t},languageData:{autocomplete:f.concat(o).concat(l).concat(c)}};export{N as webIDL};
//# sourceMappingURL=webidl-5gHnBSms.js.map
