import{e as _,ae as p,aj as m,l as s,n as f,g as c,w as d,f as g,H as y,V as v,q as k,p as n,k as w,S as I}from"./jwt-decode.esm-C7p7KYmD.js";import{u as S}from"./projectStore-JuoB0b3Z.js";import{A as T,T as j}from"./index-Bq1tJAxg.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="50e6b9da-33b0-4c8c-a298-4da50a72bc3d",e._sentryDebugIdIdentifier="sentry-dbid-50e6b9da-33b0-4c8c-a298-4da50a72bc3d")}catch{}})();const x=_({__name:"TablesTabs",setup(e){const a=p(),r=m(),i=String(r.name),u=S(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=l=>{a.push({name:String(l),params:{projectId:u.projectId}})};return(l,D)=>(c(),f(n(j),{"active-key":n(i),options:o,"onUpdate:activeKey":b},{default:d(()=>[(c(),g(y,null,v(o,t=>k(n(T),{key:t.value,name:t.value},{tab:d(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{x as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-5pNPURKY.js.map
