import"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="3e573604-f6d0-4a1f-b84c-b7e8f68448a9",x._sentryDebugIdIdentifier="sentry-dbid-3e573604-f6d0-4a1f-b84c-b7e8f68448a9")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid-BCPeGqMd.js.map
