import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-D6nI6bKL.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-C7p7KYmD.js";import{u as a}from"./projectStore-JuoB0b3Z.js";import"./router-KqhyGitc.js";import"./ts.worker-Dwx9J1L-.js";import"./fetch-Bd2rZJLr.js";import"./tables-BD2MpLEl.js";import"./string-BFwHOwI3.js";import"./SaveButton-PbUsNvUX.js";import"./ExclamationCircleOutlined-Dg5-DXrT.js";import"./CrudView-BasDvbMw.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-CGTse71O.js";import"./constants-DMOJEfPk.js";import"./url-DckRtskK.js";import"./PhDotsThreeVertical.vue-D1NfzW1g.js";import"./index-yNNUL0e-.js";import"./asyncComputed-DQBxAc8n.js";import"./PhPencil.vue-DXKUnx8k.js";import"./useCodebaseEvents-DSPYpQr7.js";import"./contracts.generated-Dr3k2sV9.js";import"./index-CEiA6CH7.js";import"./project-CR7-nfeN.js";import"./organizationSwitcher-Cqv_Kzfl.js";import"./organization-C1Ar5sAZ.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="72adc426-7c4c-42db-991e-924db3dfaa28",o._sentryDebugIdIdentifier="sentry-dbid-72adc426-7c4c-42db-991e-924db3dfaa28")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),t=new e(r.projectId);return(d,c)=>(s(),n(p,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-UqRbBOm4.js.map
