import{_ as d}from"./Login.vue_vue_type_script_setup_true_lang-cmINskXx.js";import{e as p,f as i,q as u,p as n,ae as m,aj as l,g as f,aM as _}from"./jwt-decode.esm-C7p7KYmD.js";import{u as b}from"./workspaceStore-C02eSYYX.js";import"./OTPInput-Dgj6D_cS.js";import"./Logo-DHgCZdyN.js";import"./string-BFwHOwI3.js";import"./CircularLoading-Dm1gD7nh.js";import"./index-CEiA6CH7.js";import"./userStore-Cvp-HM2T.js";import"./runnerData-tVXldQBM.js";import"./url-DckRtskK.js";import"./colorHelpers-Aow9wfUz.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c96bd777-c09b-433d-a472-ddc34d2f1442",e._sentryDebugIdIdentifier="sentry-dbid-c96bd777-c09b-433d-a472-ddc34d2f1442")}catch{}})();const g={class:"runner"},y=p({__name:"Login",setup(e){const o=m(),r=l(),t=b(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(f(),i("div",g,[u(d,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-DgvVQdWx.js.map
