import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-B67aOg2T.js";import{B as y}from"./BaseLayout-CUe9_4Hh.js";import{e as l,O as _,$ as b,aM as u,aI as v,aJ as g,g as m,f as h,k as a,F as s,M as w,ae as S,n as k,w as n,aj as I,q as i,p as $}from"./jwt-decode.esm-C7p7KYmD.js";import{u as B}from"./editor-CiW16xzQ.js";import{A as L}from"./index-D3nDWOgn.js";import"./logo-BiWG9_W5.js";import"./Logo-DHgCZdyN.js";import"./ts.worker-Dwx9J1L-.js";import"./workspaceStore-C02eSYYX.js";import"./userStore-Cvp-HM2T.js";import"./runnerData-tVXldQBM.js";import"./url-DckRtskK.js";import"./colorHelpers-Aow9wfUz.js";import"./useCodebaseEvents-DSPYpQr7.js";import"./contracts.generated-Dr3k2sV9.js";import"./files-D2kvSdSe.js";import"./PhBug.vue-DrC49-dN.js";import"./router-DSRUo_YA.js";import"./constants-DMOJEfPk.js";import"./index-yNNUL0e-.js";import"./index-Be6bmFgs.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="4711aa88-3b56-4bec-833c-c8246b862646",e._sentryDebugIdIdentifier="sentry-dbid-4711aa88-3b56-4bec-833c-c8246b862646")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),D={class:"v-spinner"};function P(e,r,o,c,d,p){return v((m(),h("div",D,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u(x,[["render",P],["__scopeId","data-v-224007fd"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=I(),o=S(),c=B();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await c.createLogin(t).then(d),o.push({name:"editor"})}),(t,A)=>(m(),k(y,null,{navbar:n(()=>[i($(L),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[a("div",j,[i(R)])]),_:1}))}}),re=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-Cb9Y5xPd.js.map
