import{z as d}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="efff7997-be2b-4625-85bf-bdfb7b7ba507",e._sentryDebugIdIdentifier="sentry-dbid-efff7997-be2b-4625-85bf-bdfb7b7ba507")}catch{}})();function h(e){return d.string().email().safeParse(e).success}function b(e){return e.trim().toLowerCase().normalize("NFD").replace(/[\u0300-\u036f]/g,"")}function p(e){return e.charAt(0).toUpperCase()+e.slice(1)}function m(e,n,r=!1,t=!0,l=!1,a=!0){const s=(t?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),o=`a-zA-Z0-9${l?"/":""}${a?"-":""}`,c=new RegExp(`[^${o}]`,"g"),f=s.replace(c,"_"),u=r?f:f.replace(/_+/g,"_");return n?u:u.replace(/_$/,"")}function w(e){const r=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g;return r.match(t)?.join("-")??""}function z(e,n){if(e.length===0||n.length===0)return!1;const r=e.toLowerCase(),t=n.toLowerCase();return r.split("").reduce((a,i)=>{if(a===!1)return!1;const s=a[a.length-1]??null;if(s===null){const o=t.indexOf(i);return o===-1?!1:[o]}else{const c=t.slice(s+1).indexOf(i);return c===-1?!1:[...a,s+1+c]}},[])}function C(e){return e.replace(/\r\n/g,`
`)}function L(e){let n=0;for(let r=0;r<e.length;r++){const t=e.charCodeAt(r);n=(n<<5)-n+t,n=n&n}return n}export{b as a,w as b,p as c,C as d,z as f,L as h,h as i,m as n};
//# sourceMappingURL=string-BFwHOwI3.js.map
