import{s as b,K as g,b as s}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="2e1de954-97fc-4fea-9964-c85b16f1dc41",n._sentryDebugIdIdentifier="sentry-dbid-2e1de954-97fc-4fea-9964-c85b16f1dc41")}catch{}})();const v=n=>{const e=b({loading:!0,result:null,error:null});let l=null,o=0;const a=(r,t)=>(t===o&&(e.value={loading:!1,result:r,error:null}),r),d=(r,t)=>{t===o&&r.name!=="AbortError"&&(e.value={loading:!1,result:null,error:r})},u=async()=>{l&&l.abort(),l=new AbortController;const r=++o;return e.value={loading:!0,result:e.value.result,error:null},n().then(t=>a(t,r)).catch(t=>d(t,r))};u(),g(()=>{l&&l.abort()});const c=s(()=>e.value.loading),f=s(()=>e.value.result),i=s(()=>e.value.error);return{loading:c,result:f,error:i,refetch:u}};export{v as a};
//# sourceMappingURL=asyncComputed-DQBxAc8n.js.map
