import{q as l,a9 as f,ab as o}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c6449d0f-81c2-49e8-b9ce-e3c9fa6a6668",e._sentryDebugIdIdentifier="sentry-dbid-c6449d0f-81c2-49e8-b9ce-e3c9fa6a6668")}catch{}})();function c(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(a){return Object.getOwnPropertyDescriptor(r,a).enumerable}))),n.forEach(function(a){u(e,a,r[a])})}return e}function u(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var i=function(t,r){var n=c({},t,r.attrs);return l(f,c({},n,{icon:o}),null)};i.displayName="CloseCircleOutlined";i.inheritAttrs=!1;export{i as C};
//# sourceMappingURL=CloseCircleOutlined-ClZGXsIx.js.map
