(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[e]="995f4c92-997e-468e-84da-ff664ff3c382",i._sentryDebugIdIdentifier="sentry-dbid-995f4c92-997e-468e-84da-ff664ff3c382")}catch{}})();const l={name:"properties",token:function(i,e){var o=i.sol()||e.afterSection,f=i.eol();if(e.afterSection=!1,o&&(e.nextMultiline?(e.inMultiline=!0,e.nextMultiline=!1):e.position="def"),f&&!e.nextMultiline&&(e.inMultiline=!1,e.position="def"),o)for(;i.eatSpace(););var n=i.next();return o&&(n==="#"||n==="!"||n===";")?(e.position="comment",i.skipToEnd(),"comment"):o&&n==="["?(e.afterSection=!0,i.skipTo("]"),i.eat("]"),"header"):n==="="||n===":"?(e.position="quote",null):(n==="\\"&&e.position==="quote"&&i.eol()&&(e.nextMultiline=!0),e.position)},startState:function(){return{position:"def",nextMultiline:!1,inMultiline:!1,afterSection:!1}}};export{l as properties};
//# sourceMappingURL=properties-DExTFT-Z.js.map
