.form-label[data-v-82ead59b]{display:inline-flex;align-items:center;gap:6px}.form-label-info-icon[data-v-82ead59b]{color:var(--ac-text-secondary, #8c8c8c);cursor:help;transition:color .15s ease}.form-label-info-icon[data-v-82ead59b]:hover{color:var(--ac-text-primary, #262626)}
