import{N as c}from"./Navbar-DS0DIN5_.js";import{e as d,aj as u,b as a,l,a2 as _,f,g as b,q as p,k as y,aM as I}from"./jwt-decode.esm-C7p7KYmD.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-DEp2OjRm.js";import"./LoadingOutlined-BqTEfowm.js";import"./constants-DMOJEfPk.js";import"./PhCaretDown.vue-7Cgxwhgw.js";import"./PhPencilSimple.vue-2bYJweno.js";import"./router-KqhyGitc.js";import"./ts.worker-Dwx9J1L-.js";import"./organization-C1Ar5sAZ.js";import"./tables-BD2MpLEl.js";import"./string-BFwHOwI3.js";import"./keyboard-9QwaFoaS.js";import"./os-B-YefhmF.js";import"./projectStore-JuoB0b3Z.js";import"./project-CR7-nfeN.js";import"./organizationSwitcher-Cqv_Kzfl.js";import"./cascaderStore-BvBcLa9w.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-YlPuldtr.js";import"./member-DiXowP2D.js";import"./index-Mklv1swQ.js";import"./index-Bq1tJAxg.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-Dg0LqeHW.js";import"./PhNotePencil.vue-Dqtfrxda.js";import"./PhSignOut.vue-nFdqLb5g.js";import"./index-yNNUL0e-.js";import"./index-Be6bmFgs.js";import"./PhPlus.vue-BLN85bUj.js";import"./omniChatStore-CKovejdx.js";import"./files-D2kvSdSe.js";import"./contracts.generated-Dr3k2sV9.js";import"./runnerData-tVXldQBM.js";import"./url-DckRtskK.js";import"./colorHelpers-Aow9wfUz.js";import"./uuid-BCPeGqMd.js";import"./PhCopySimple.vue-Bun6F74y.js";import"./PhSparkle.vue-D6TF2A7G.js";import"./index-D3nDWOgn.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8724e216-2287-4dc4-bd9b-9abed0e0189e",e._sentryDebugIdIdentifier="sentry-dbid-8724e216-2287-4dc4-bd9b-9abed0e0189e")}catch{}})();const g={class:"console-layout"},v={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=_("RouterView");return b(),f("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",v,[p(r)])])}}}),po=I(w,[["__scopeId","data-v-62f8634d"]]);export{po as default};
//# sourceMappingURL=ConsoleLayout-7-dPBabt.js.map
