import{_ as n,e as f,l as u}from"./NewEditor-J5bBywjE.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="422c30ab-642f-46d6-9950-f18dd94e4bcf",e._sentryDebugIdIdentifier="sentry-dbid-422c30ab-642f-46d6-9950-f18dd94e4bcf")}catch{}})();var l=n((e,t,i,r)=>{e.attr("class",i);const{width:o,height:d,x:a,y:c}=w(e,t);f(e,d,o,r);const s=h(a,c,o,d,t);e.attr("viewBox",s),u.debug(`viewBox configured: ${s} with padding: ${t}`)},"setupViewPortForSVG"),w=n((e,t)=>{const i=e.node()?.getBBox()||{width:0,height:0,x:0,y:0};return{width:i.width+t*2,height:i.height+t*2,x:i.x,y:i.y}},"calculateDimensionsWithPadding"),h=n((e,t,i,r,o)=>`${e-o} ${t-o} ${i} ${r}`,"createViewBox");export{l as s};
//# sourceMappingURL=chunk-KX2RTZJC-znOv0_WA.js.map
