.api-keys-view[data-v-3466df93]{width:100%}.constraint-editor[data-v-3466df93]{height:60px;margin-top:4px;border:1px solid var(--ac-border-primary, #d9d9d9);border-radius:4px;overflow:hidden}.sparkle-btn[data-v-3466df93]{color:var(--ac-brand-primary)!important}.sparkle-btn[data-v-3466df93]:hover{color:var(--ac-brand-primary-hover)!important}
