import{e as B,b as i,n as a,g as s,p as o,A as h,w as r,q as k,B as u,t as f,v,k as y,h as b,j as g,m as w}from"./jwt-decode.esm-C7p7KYmD.js";import{L as _}from"./LoadingOutlined-BqTEfowm.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="7c52a736-c601-41b0-8df3-b37f73ac8e9c",t._sentryDebugIdIdentifier="sentry-dbid-7c52a736-c601-41b0-8df3-b37f73ac8e9c")}catch{}})();const x={style:{display:"inline-flex","align-items":"center","justify-content":"center",gap:"5px"}},T={style:{display:"inline-flex","align-items":"center","justify-content":"center",gap:"5px"}},I=B({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,l=i(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip),d=i(()=>!!e.loading),p=i(()=>{const{loading:n,disabled:c,...m}=e;return{...m,disabled:c||!!n}});return(n,c)=>l.value?(s(),a(o(h),{key:0,title:l.value},{default:r(()=>[k(o(u),f(v(p.value)),{default:r(()=>[y("span",x,[b(n.$slots,"default"),d.value?(s(),a(o(_),{key:0})):g("",!0)])]),_:3},16)]),_:3},8,["title"])):(s(),a(o(u),f(w({key:1},p.value)),{default:r(()=>[y("span",T,[b(n.$slots,"default"),d.value?(s(),a(o(_),{key:0})):g("",!0)])]),_:3},16))}});export{I as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang-DEp2OjRm.js.map
