import{B as l}from"./BaseLayout-CUe9_4Hh.js";import{C as p}from"./ContentLayout-CjSx9x5N.js";import{e as f,aj as _,b as i,C as b,a2 as g,n as r,g as s,w as m,q as y,j as w}from"./jwt-decode.esm-C7p7KYmD.js";import{_ as z}from"./BillingAlert.vue_vue_type_script_setup_true_lang-eN3YQobu.js";import{u as h}from"./projectsStore-CG9meR0x.js";import"./router-KqhyGitc.js";import"./ts.worker-Dwx9J1L-.js";import"./index-CEiA6CH7.js";import"./member-DiXowP2D.js";import"./organization-C1Ar5sAZ.js";import"./project-CR7-nfeN.js";import"./tables-BD2MpLEl.js";import"./string-BFwHOwI3.js";import"./cascaderStore-BvBcLa9w.js";import"./organizationSwitcher-Cqv_Kzfl.js";import"./ant-design-HOXKf1iD.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="356b23da-7c5a-43eb-9d04-52d97debf1c9",t._sentryDebugIdIdentifier="sentry-dbid-356b23da-7c5a-43eb-9d04-52d97debf1c9")}catch{}})();const P=f({__name:"Organization",setup(t){const e=_(),a=h(),n=i(()=>e.params.organizationId);b(n,o=>{o&&a.fetchedState?.organization?.id!==o&&a.fetchState(o)},{immediate:!0});const c=i(()=>a.fetchedState?.organization),d=i(()=>c.value?.billingMetadata);return(o,v)=>{const u=g("RouterView");return s(),r(l,null,{content:m(()=>[y(p,null,{default:m(()=>[d.value?(s(),r(z,{key:0,"billing-metadata":d.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(u,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-2ov6fqUy.js.map
