import{e as _,ae as g,r as y,M as b,f as m,g as n,n as d,w as s,q as l,p as r,ai as w,R as u,S as f,B as v,l as p,b5 as R,bc as h,aM as k}from"./jwt-decode.esm-C7p7KYmD.js";import{u as x}from"./organizationSwitcher-Cqv_Kzfl.js";import"./router-KqhyGitc.js";import"./ts.worker-Dwx9J1L-.js";import"./organization-C1Ar5sAZ.js";import"./tables-BD2MpLEl.js";import"./string-BFwHOwI3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6a89197c-0162-40cc-8b16-fb153dcbc0ec",e._sentryDebugIdIdentifier="sentry-dbid-6a89197c-0162-40cc-8b16-fb153dcbc0ec")}catch{}})();const D={class:"loading-container"},I=_({__name:"RootRedirector",setup(e){const a=x(),c=g(),o=y(null);async function i(){o.value=null;try{const t=await a.selectDefaultOrganization();t.name==="onboarding"?window.location.href="/onboarding":c.replace(t)}catch(t){o.value=p.translate("i18n_projectsview_loading_error"),console.error("RootRedirector failed:",t)}}return b(i),(t,B)=>(n(),m("div",D,[o.value?(n(),d(r(R),{key:0,vertical:"",align:"center",gap:16},{default:s(()=>[l(r(w),{type:"danger"},{default:s(()=>[u(f(o.value),1)]),_:1}),l(r(v),{type:"primary",onClick:i},{default:s(()=>[u(f(r(p).translate("i18n_projectsview_retry")),1)]),_:1})]),_:1})):(n(),d(r(h),{key:1,size:"large"}))]))}}),O=k(I,[["__scopeId","data-v-c1eea334"]]);export{O as default};
//# sourceMappingURL=RootRedirector-Dgh1baom.js.map
