(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="dba757a6-58d5-4fe6-9901-15e83c059f56",e._sentryDebugIdIdentifier="sentry-dbid-dba757a6-58d5-4fe6-9901-15e83c059f56")}catch{}})();var f={"+":"inserted","-":"deleted","@":"meta"};const o={name:"diff",token:function(e){var n=e.string.search(/[\t ]+?$/);if(!e.sol()||n===0)return e.skipToEnd(),("error "+(f[e.string.charAt(0)]||"")).replace(/ $/,"");var d=f[e.peek()]||e.skipToEnd();return n===-1?e.skipToEnd():e.pos=n,d}};export{o as diff};
//# sourceMappingURL=diff-Blsup9Ad.js.map
