import{q as o,a9 as d,aa as u}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="48e4629b-51e1-4d8a-b07c-e400ff299b8a",e._sentryDebugIdIdentifier="sentry-dbid-48e4629b-51e1-4d8a-b07c-e400ff299b8a")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){l(e,a,n[a])})}return e}function l(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=i({},t,n.attrs);return o(d,i({},r,{icon:u}),null)};f.displayName="LoadingOutlined";f.inheritAttrs=!1;export{f as L};
//# sourceMappingURL=LoadingOutlined-BqTEfowm.js.map
