import{u as r}from"./userStore-Cvp-HM2T.js";import{W as n}from"./PlayerConfigProvider-BME6hC-N.js";import{u as c}from"./workspaceStore-C02eSYYX.js";import{e as i,C as d,n as f,j as m,p as o,w as u,q as p,a2 as l,g as w}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="3377837e-5005-4bb1-a340-a7d23ef81919",t._sentryDebugIdIdentifier="sentry-dbid-3377837e-5005-4bb1-a340-a7d23ef81919")}catch{}})();const C=i({__name:"App",setup(t){document.documentElement.dataset.theme="light";const a=r(),e=c();return e.actions.fetch(),d(()=>a.jwt,e.actions.fetch),(_,g)=>{const s=l("RouterView");return o(e).state.workspace?(w(),f(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[p(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):m("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-B01hCRw3.js.map
