import{_ as t}from"./NewEditor-J5bBywjE.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="cb218938-0976-4a71-aa0c-8918147a9cd2",e._sentryDebugIdIdentifier="sentry-dbid-cb218938-0976-4a71-aa0c-8918147a9cd2")}catch{}})();function i(e,c){e.accDescr&&c.setAccDescription?.(e.accDescr),e.accTitle&&c.setAccTitle?.(e.accTitle),e.title&&c.setDiagramTitle?.(e.title)}t(i,"populateCommonDb");export{i as p};
//# sourceMappingURL=chunk-4BX2VUAB-Bj8c3ALV.js.map
