import{_ as i}from"./NewEditor-J5bBywjE.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="64e03129-0793-47fe-b52e-8b7f360bc43e",t._sentryDebugIdIdentifier="sentry-dbid-64e03129-0793-47fe-b52e-8b7f360bc43e")}catch{}})();var e,d=(e=class{constructor(s){this.init=s,this.records=this.init()}reset(){this.records=this.init()}},i(e,"ImperativeState"),e);export{d as I};
//# sourceMappingURL=chunk-QZHKN3VN-C2zuSNjo.js.map
