import{aV as r,aW as n,a3 as o,aX as d,aY as p,aZ as c,a_ as f,a$ as m,b0 as u,b1 as s,b2 as g,b3 as b,b4 as l}from"./jwt-decode.esm-C7p7KYmD.js";import{b as y,s as w,g as _}from"./workspaceStore-C02eSYYX.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-B01hCRw3.js";import{r as i}from"./router-DSRUo_YA.js";import"./userStore-Cvp-HM2T.js";import"./runnerData-tVXldQBM.js";import"./url-DckRtskK.js";import"./colorHelpers-Aow9wfUz.js";import"./PlayerConfigProvider-BME6hC-N.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="48de2f7e-d8c5-4502-8457-149971e31def",t._sentryDebugIdIdentifier="sentry-dbid-48de2f7e-d8c5-4502-8457-149971e31def")}catch{}})();class I{static init(){setInterval(()=>{y("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await _(),a=r(),e=n({render:()=>o(h)});d.init(),p(e,i,t),I.init(),e.use(i),e.use(a),e.use(c),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",m),e.component("Message",u),s(e,g),s(e,b),s(e,l)})();
//# sourceMappingURL=player-CxDYkQj_.js.map
