.table-card[data-v-a12e1c88]{height:100%;width:100%;transition:all .2s ease;box-shadow:0 1px 3px var(--ac-shadow-color)}.table-card[data-v-a12e1c88]:hover{transform:translateY(-2px);box-shadow:0 4px 12px var(--ac-shadow-color)}.columns-list[data-v-a12e1c88]{max-height:280px;overflow-y:auto;overflow-x:hidden}.column-row[data-v-a12e1c88]{padding:3px 4px;position:relative;min-width:0;border-radius:4px;transition:background-color .15s ease}.column-highlighted[data-v-a12e1c88],.more-columns-highlighted[data-v-a12e1c88]{background-color:var(--ac-bg-hover)}.table-highlighted[data-v-a12e1c88]{border:2px solid var(--ac-brand-link);box-shadow:0 0 0 2px var(--ac-brand-accent-tint),0 2px 8px var(--ac-shadow-color)}.key-icon[data-v-a12e1c88]{color:var(--ac-color-warning-indicator);flex-shrink:0}.delete-btn[data-v-a12e1c88]{opacity:0;background:none;border:none;padding:4px;cursor:pointer;color:var(--ac-text-tertiary);border-radius:4px;display:flex;align-items:center;justify-content:center;transition:all .15s ease}.delete-btn[data-v-a12e1c88]:hover{color:var(--ac-color-error);background-color:var(--ac-color-error-bg)}.delete-btn[data-v-a12e1c88]:focus-visible{opacity:1;outline:2px solid var(--ac-focus-ring);outline-offset:1px}.table-card:hover .delete-btn[data-v-a12e1c88]{opacity:1}.type-tag[data-v-a12e1c88]{font-size:11px;padding:0 6px;margin:0;border-radius:4px;white-space:nowrap;flex-shrink:0}
