DOT_ABSTRA_DIR = ".abstra"

LOCAL_LOGS_DIR_PATH = f"{DOT_ABSTRA_DIR}/logs"
TASKS_DIR_PATH = f"{DOT_ABSTRA_DIR}/tasks"
EXECUTIONS_DIR_PATH = f"{DOT_ABSTRA_DIR}/executions"
WEB_EDITOR_HEARTBEAT_FILE_PATH = f"{DOT_ABSTRA_DIR}/.web_editor_heartbeat.json"
PERSISTENT_DIR_PATH = f"{DOT_ABSTRA_DIR}/persistent"
CACHED_VERSIONS_DIR_PATH = f"{DOT_ABSTRA_DIR}/cached_versions"
CONFIG_BACKUP_DIR_PATH = f"{DOT_ABSTRA_DIR}/config_file_backups"
ABSTRA_JSON_TEMP_DIR_PATH = f"{DOT_ABSTRA_DIR}/temp"

AI_UPLOADS_DIR_PATH = f"{DOT_ABSTRA_DIR}/ai_uploads"
SMARTCHAT_SNIPPETS_DIR_PATH = f"{DOT_ABSTRA_DIR}/smartchat_snippets"

CREDENTIALS_FILEPATH = f"{DOT_ABSTRA_DIR}/credentials"
TEST_DATA_FILEPATH = f"{DOT_ABSTRA_DIR}/test_data.json"

GIT_DIR_PATH = ".git"
GITIGNORE_FILEPATH = ".gitignore"
ABSTRA_TABLES_FILEPATH = "abstra-tables.json"
