import{ak as d}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e72a1fc2-02db-4d62-a15b-4c99b3a1a974",e._sentryDebugIdIdentifier="sentry-dbid-e72a1fc2-02db-4d62-a15b-4c99b3a1a974")}catch{}})();var a=4;function o(e){return d(e,a)}export{o as c};
//# sourceMappingURL=clone-YJaWU1nU.js.map
