import{e as i,b as o,f as t,j as r,E as l,S as f,bh as g,g as a,aM as u}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ce97e9d7-2491-4f5e-8bf7-ebc9bbd21d0e",e._sentryDebugIdIdentifier="sentry-dbid-ce97e9d7-2491-4f5e-8bf7-ebc9bbd21d0e")}catch{}})();const b={class:"logo"},m=["src","alt"],y=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){g(c=>({v4521d904:n.value}));const s=e,n=o(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),d=o(()=>`${s.brandName} Logo`);return(c,p)=>(a(),t("div",b,[e.imageUrl?(a(),t("img",{key:0,class:"logo-img",src:e.imageUrl,alt:d.value},null,8,m)):r("",!0),e.hideText?r("",!0):(a(),t("span",{key:1,class:l(e.size)},f(e.brandName),3))]))}}),_=u(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-DHgCZdyN.js.map
