import{O as l}from"./workspaceStore-C02eSYYX.js";import{e as c,M as u,f,q as o,w as n,p as a,al as _,ai as p,R as r,S as d,l as s,g as b}from"./jwt-decode.esm-C7p7KYmD.js";import"./userStore-Cvp-HM2T.js";import"./runnerData-tVXldQBM.js";import"./url-DckRtskK.js";import"./colorHelpers-Aow9wfUz.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5038c2c3-cc3a-43d9-b4dd-e20ff8d1b70a",e._sentryDebugIdIdentifier="sentry-dbid-5038c2c3-cc3a-43d9-b4dd-e20ff8d1b70a")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(t,i)=>(b(),f("div",null,[o(a(_),null,{default:n(()=>[r(d(a(s).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(d(a(s).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-0qMiyfQj.js.map
