.credentials-page[data-v-f9bd641e]{min-height:100vh;display:flex;align-items:center;justify-content:center;padding:20px;background-color:var(--ac-surface-secondary, #f5f5f5)}.credentials-card[data-v-f9bd641e]{max-width:500px;width:100%}
