import{_ as r}from"./logo-BiWG9_W5.js";import{L as o}from"./Logo-DHgCZdyN.js";import{e as s,n as a,p as i,g as b}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b4e43b99-8318-4ebb-a562-73e253b27b92",e._sentryDebugIdIdentifier="sentry-dbid-b4e43b99-8318-4ebb-a562-73e253b27b92")}catch{}})();const u=s({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(b(),a(o,{"image-url":i(r),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-B67aOg2T.js.map
