import{A as a}from"./index-BMpT7rIm.js";import{e as n,b as o,f as r,j as c,E as f,q as d,p as l,g as p,aM as i}from"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="a5964a38-3612-4a17-98ac-7d84a342ae3f",e._sentryDebugIdIdentifier="sentry-dbid-a5964a38-3612-4a17-98ac-7d84a342ae3f")}catch{}})();const u=n({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,y)=>e.stepsInfo?(p(),r("nav",{key:0,class:f(["p-steps",{"full-screen":!e.isPreview}])},[d(l(a),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-BLjKkl-k.js.map
