import{L as u}from"./CircularLoading-Dm1gD7nh.js";import{e as f,aj as p,M as _,f as h,g as l,k as c,q as g,aM as m}from"./jwt-decode.esm-C7p7KYmD.js";import{E as a,a as y}from"./router-KqhyGitc.js";import"./ts.worker-Dwx9J1L-.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4128dfbf-2cd2-4847-9a7d-ec394a3d70ce",e._sentryDebugIdIdentifier="sentry-dbid-4128dfbf-2cd2-4847-9a7d-ec394a3d70ce")}catch{}})();const w={class:"authorize"},b={class:"content"},A=f({__name:"Authorize",setup(e){const o=p();return _(()=>{const{client_id:r,redirect_uri:s,response_type:n,state:i}=o.query,t=a.cloudApi.startsWith("https://")||a.cloudApi.startsWith("http://")?new URL(`${a.cloudApi}/oauth/authorize`):new URL(`${location.origin}${a.cloudApi}/oauth/authorize`);typeof r=="string"&&t.searchParams.set("client_id",r),typeof s=="string"&&t.searchParams.set("redirect_uri",s),typeof n=="string"&&t.searchParams.set("response_type",n),typeof i=="string"&&t.searchParams.set("state",i);const d=y.getAuthor();d?.jwt&&t.searchParams.set("session_token",d.jwt),window.location.href=t.toString()}),(r,s)=>(l(),h("div",w,[c("div",b,[s[0]||(s[0]=c("h1",null,"Authorizing...",-1)),g(u)])]))}}),L=m(A,[["__scopeId","data-v-57fe5408"]]);export{L as default};
//# sourceMappingURL=Authorize-ubG4fl-D.js.map
