import{P as h}from"./PlayerNavbar-BRpy00M4.js";import{e as _,aj as y,r as k,b as w,f as b,n as d,j as v,k as L,p as o,a2 as C,ae as I,g as s,aM as N}from"./jwt-decode.esm-C7p7KYmD.js";import{u as P}from"./workspaceStore-C02eSYYX.js";import"./userStore-Cvp-HM2T.js";import"./metadata--B3wAPVN.js";import"./PhCursorClick.vue-R7PVFNVB.js";import"./PhHouse.vue-CJ1VeqtB.js";import"./PhMagnifyingGlass.vue-DNEPEcIe.js";import"./PhWebhooksLogo.vue-g_Zstsmg.js";import"./LoadingOutlined-BqTEfowm.js";import"./PhSignOut.vue-nFdqLb5g.js";import"./index-Be6bmFgs.js";import"./runnerData-tVXldQBM.js";import"./url-DckRtskK.js";import"./colorHelpers-Aow9wfUz.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d5d75de8-f27f-46e7-9f21-e58470363f06",t._sentryDebugIdIdentifier="sentry-dbid-d5d75de8-f27f-46e7-9f21-e58470363f06")}catch{}})();const B={class:"main-container"},D={class:"content"},R=_({__name:"Main",setup(t){const e=I(),a=y(),n=P(),u=a.path,r=k(null),p=async({path:i,id:c})=>{r.value=c,await e.push({path:`/${i}`}),r.value=null},l=()=>{e.push({name:"playerLogin"})},m=()=>{e.push({name:"playerLogin"})},f=w(()=>!!a.meta.hideLogin);return(i,c)=>{const g=C("RouterView");return s(),b("div",B,[o(n).state.workspace?(s(),d(h,{key:0,"current-path":o(u),"hide-login":f.value,"runner-data":o(n).state.workspace,loading:r.value,"show-sidebar":o(n).state.currentPageType==="form",onNavigate:p,onLoginClick:m,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):v("",!0),L("section",D,[(s(),d(g,{key:o(a).fullPath}))])])}}}),J=N(R,[["__scopeId","data-v-ba04162e"]]);export{J as default};
//# sourceMappingURL=Main-Blp9lfwb.js.map
