.project-layout[data-v-460dc297]{display:flex;flex-direction:column;height:100%;overflow:hidden}.project-layout .project-navbar[data-v-460dc297]{flex-shrink:0;width:100%;border-bottom:1px solid var(--ac-border-primary)}.project-layout .project-body[data-v-460dc297]{display:flex;flex-grow:1;overflow:hidden}.project-layout .project-body .project-sidebar[data-v-460dc297]{flex-shrink:0;overflow-y:auto}.project-layout .project-body .project-content[data-v-460dc297]{flex-grow:1;overflow:auto}.project-layout .project-body .resize-handle[data-v-460dc297]{width:4px;height:100%;cursor:col-resize;background:transparent;position:relative;flex-shrink:0;display:flex;align-items:center;justify-content:center}.project-layout .project-body .resize-handle[data-v-460dc297]:before{content:"";width:1px;height:100%;background:var(--ac-border-primary);transition:background-color .15s ease,width .15s ease}.project-layout .project-body .resize-handle[data-v-460dc297]:hover:before{width:2px;background:var(--ac-brand-primary);opacity:.5}.project-layout .project-body .resize-handle[data-v-460dc297]:active:before{width:2px;background:var(--ac-brand-primary);opacity:.8}.project-layout .project-body .project-chat[data-v-460dc297]{flex-shrink:0;overflow:hidden}
