.credentials-page[data-v-3126c1e9]{min-height:100vh;display:flex;align-items:center;justify-content:center;padding:20px;background-color:var(--ac-surface-secondary, #f5f5f5)}.loading-container[data-v-3126c1e9],.error-container[data-v-3126c1e9]{display:flex;align-items:center;justify-content:center;min-height:400px}.credentials-card[data-v-3126c1e9]{max-width:500px;width:100%}.error-container[data-v-3126c1e9] .ant-result-title,.error-container[data-v-3126c1e9] .ant-result-extra,.error-text[data-v-3126c1e9]{color:#000!important}
