(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="6706b9f7-373b-4aaa-87c8-8f2c579adab0",n._sentryDebugIdIdentifier="sentry-dbid-6706b9f7-373b-4aaa-87c8-8f2c579adab0")}catch{}})();function H(n){return Math.abs(n=Math.round(n))>=1e21?n.toLocaleString("en").replace(/,/g,""):n.toString(10)}function j(n,t){if(!isFinite(n)||n===0)return null;var e=(n=t?n.toExponential(t-1):n.toExponential()).indexOf("e"),i=n.slice(0,e);return[i.length>1?i[0]+i.slice(2):i,+n.slice(e+1)]}function J(n){return n=j(Math.abs(n)),n?n[1]:NaN}function K(n,t){return function(e,i){for(var o=e.length,a=[],c=0,s=n[0],x=0;o>0&&s>0&&(x+s+1>i&&(s=Math.max(1,i-x)),a.push(e.substring(o-=s,o+s)),!((x+=s+1)>i));)s=n[c=(c+1)%n.length];return a.reverse().join(t)}}function Q(n){return function(t){return t.replace(/[0-9]/g,function(e){return n[+e]})}}var V=/^(?:(.)?([<>=^]))?([+\-( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?(~)?([a-z%])?$/i;function D(n){if(!(t=V.exec(n)))throw new Error("invalid format: "+n);var t;return new F({fill:t[1],align:t[2],sign:t[3],symbol:t[4],zero:t[5],width:t[6],comma:t[7],precision:t[8]&&t[8].slice(1),trim:t[9],type:t[10]})}D.prototype=F.prototype;function F(n){this.fill=n.fill===void 0?" ":n.fill+"",this.align=n.align===void 0?">":n.align+"",this.sign=n.sign===void 0?"-":n.sign+"",this.symbol=n.symbol===void 0?"":n.symbol+"",this.zero=!!n.zero,this.width=n.width===void 0?void 0:+n.width,this.comma=!!n.comma,this.precision=n.precision===void 0?void 0:+n.precision,this.trim=!!n.trim,this.type=n.type===void 0?"":n.type+""}F.prototype.toString=function(){return this.fill+this.align+this.sign+this.symbol+(this.zero?"0":"")+(this.width===void 0?"":Math.max(1,this.width|0))+(this.comma?",":"")+(this.precision===void 0?"":"."+Math.max(0,this.precision|0))+(this.trim?"~":"")+this.type};function W(n){n:for(var t=n.length,e=1,i=-1,o;e<t;++e)switch(n[e]){case".":i=o=e;break;case"0":i===0&&(i=e),o=e;break;default:if(!+n[e])break n;i>0&&(i=0);break}return i>0?n.slice(0,i)+n.slice(o+1):n}var E;function v(n,t){var e=j(n,t);if(!e)return E=void 0,n.toPrecision(t);var i=e[0],o=e[1],a=o-(E=Math.max(-8,Math.min(8,Math.floor(o/3)))*3)+1,c=i.length;return a===c?i:a>c?i+new Array(a-c+1).join("0"):a>0?i.slice(0,a)+"."+i.slice(a):"0."+new Array(1-a).join("0")+j(n,Math.max(0,t+a-1))[0]}function G(n,t){var e=j(n,t);if(!e)return n+"";var i=e[0],o=e[1];return o<0?"0."+new Array(-o).join("0")+i:i.length>o+1?i.slice(0,o+1)+"."+i.slice(o+1):i+new Array(o-i.length+2).join("0")}const X={"%":(n,t)=>(n*100).toFixed(t),b:n=>Math.round(n).toString(2),c:n=>n+"",d:H,e:(n,t)=>n.toExponential(t),f:(n,t)=>n.toFixed(t),g:(n,t)=>n.toPrecision(t),o:n=>Math.round(n).toString(8),p:(n,t)=>G(n*100,t),r:G,s:v,X:n=>Math.round(n).toString(16).toUpperCase(),x:n=>Math.round(n).toString(16)};function O(n){return n}var R=Array.prototype.map,U=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"];function nn(n){var t=n.grouping===void 0||n.thousands===void 0?O:K(R.call(n.grouping,Number),n.thousands+""),e=n.currency===void 0?"":n.currency[0]+"",i=n.currency===void 0?"":n.currency[1]+"",o=n.decimal===void 0?".":n.decimal+"",a=n.numerals===void 0?O:Q(R.call(n.numerals,String)),c=n.percent===void 0?"%":n.percent+"",s=n.minus===void 0?"−":n.minus+"",x=n.nan===void 0?"NaN":n.nan+"";function $(f,g){f=D(f);var l=f.fill,p=f.align,h=f.sign,M=f.symbol,S=f.zero,I=f.width,N=f.comma,y=f.precision,L=f.trim,d=f.type;d==="n"?(N=!0,d="g"):X[d]||(y===void 0&&(y=12),L=!0,d="g"),(S||l==="0"&&p==="=")&&(S=!0,l="0",p="=");var Z=(g&&g.prefix!==void 0?g.prefix:"")+(M==="$"?e:M==="#"&&/[boxX]/.test(d)?"0"+d.toLowerCase():""),q=(M==="$"?i:/[%p]/.test(d)?c:"")+(g&&g.suffix!==void 0?g.suffix:""),T=X[d],B=/[defgprs%]/.test(d);y=y===void 0?6:/[gprs]/.test(d)?Math.max(1,Math.min(21,y)):Math.max(0,Math.min(20,y));function _(r){var b=Z,u=q,w,C,k;if(d==="c")u=T(r)+u,r="";else{r=+r;var P=r<0||1/r<0;if(r=isNaN(r)?x:T(Math.abs(r),y),L&&(r=W(r)),P&&+r==0&&h!=="+"&&(P=!1),b=(P?h==="("?h:s:h==="-"||h==="("?"":h)+b,u=(d==="s"&&!isNaN(r)&&E!==void 0?U[8+E/3]:"")+u+(P&&h==="("?")":""),B){for(w=-1,C=r.length;++w<C;)if(k=r.charCodeAt(w),48>k||k>57){u=(k===46?o+r.slice(w+1):r.slice(w))+u,r=r.slice(0,w);break}}}N&&!S&&(r=t(r,1/0));var z=b.length+r.length+u.length,m=z<I?new Array(I-z+1).join(l):"";switch(N&&S&&(r=t(m+r,m.length?I-u.length:1/0),m=""),p){case"<":r=b+r+u+m;break;case"=":r=b+m+r+u;break;case"^":r=m.slice(0,z=m.length>>1)+b+r+u+m.slice(z);break;default:r=m+b+r+u;break}return a(r)}return _.toString=function(){return f+""},_}function Y(f,g){var l=Math.max(-8,Math.min(8,Math.floor(J(g)/3)))*3,p=Math.pow(10,-l),h=$((f=D(f),f.type="f",f),{suffix:U[8+l/3]});return function(M){return h(p*M)}}return{format:$,formatPrefix:Y}}var A,tn,rn;en({thousands:",",grouping:[3],currency:["$",""]});function en(n){return A=nn(n),tn=A.format,rn=A.formatPrefix,A}export{rn as a,tn as b,J as e,D as f};
//# sourceMappingURL=defaultLocale-CQyarIpD.js.map
