import{O as d}from"./workspaceStore-C02eSYYX.js";import{e as c,M as f,f as u,q as n,w as o,p as t,al as _,ai as p,R as r,S as i,l as s,g as b}from"./jwt-decode.esm-C7p7KYmD.js";import"./userStore-Cvp-HM2T.js";import"./runnerData-tVXldQBM.js";import"./url-DckRtskK.js";import"./colorHelpers-Aow9wfUz.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a9042627-94a8-4e0e-a15d-3d6f6157b1fa",e._sentryDebugIdIdentifier="sentry-dbid-a9042627-94a8-4e0e-a15d-3d6f6157b1fa")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new d().loginCallback()}),(a,l)=>(b(),u("div",null,[n(t(_),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(t(p),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-D7Tq7zCj.js.map
