import"./jwt-decode.esm-C7p7KYmD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="7db89723-bfd8-492d-90c0-c8a91a70aff9",e._sentryDebugIdIdentifier="sentry-dbid-7db89723-bfd8-492d-90c0-c8a91a70aff9")}catch{}})();const r=e=>{if(e==null)return"";const n=typeof e=="object"?JSON.stringify(e):String(e);return n.includes(";")||n.includes(`
`)||n.includes('"')?`"${n.replace(/"/g,'""')}"`:n},i=e=>{const n=e.columns.map(r).join(";"),t=e.rows.map(s=>s.map(r).join(";"));return[n,...t].join(`
`)+`
`},c="\uFEFF",l=e=>e.replace(/[\\/:*?"<>|]/g,"-"),f=e=>{const n=i(e),t=document.createElement("a");t.href="data:text/csv;charset=utf-8,"+encodeURIComponent(c+n),t.target="_blank",t.download=`${l(e.fileName)}.csv`,t.click()},u=(e,n)=>Array.isArray(n)?n.reduce((t,s)=>t==null?t:t[s],e):e[n],b=e=>{const n=e.columns.filter(o=>o.dataIndex!==void 0),t=n.map(o=>String(o.title??o.dataIndex)),s=e.rows.map(o=>n.map(d=>u(o,d.dataIndex))),a=e.fileName??`data-${new Date().toISOString()}`;f({fileName:a,columns:t,rows:s})};export{b as d};
//# sourceMappingURL=csv-BmGYrsMa.js.map
