(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[n]="a92d5f8c-061f-4c68-bc19-234d386ec9f4",r._sentryDebugIdIdentifier="sentry-dbid-a92d5f8c-061f-4c68-bc19-234d386ec9f4")}catch{}})();function u(r,n){return r.skipToEnd(),n.cur=t,"error"}function i(r,n){return r.match(/^HTTP\/\d\.\d/)?(n.cur=d,"keyword"):r.match(/^[A-Z]+/)&&/[ \t]/.test(r.peek())?(n.cur=s,"keyword"):u(r,n)}function d(r,n){var e=r.match(/^\d+/);if(!e)return u(r,n);n.cur=f;var o=Number(e[0]);return o>=100&&o<400?"atom":"error"}function f(r,n){return r.skipToEnd(),n.cur=t,null}function s(r,n){return r.eatWhile(/\S/),n.cur=l,"string.special"}function l(r,n){return r.match(/^HTTP\/\d\.\d$/)?(n.cur=t,"keyword"):u(r,n)}function t(r){return r.sol()&&!r.eat(/[ \t]/)?r.match(/^.*?:/)?"atom":(r.skipToEnd(),"error"):(r.skipToEnd(),"string")}function c(r){return r.skipToEnd(),null}const a={name:"http",token:function(r,n){var e=n.cur;return e!=t&&e!=c&&r.eatSpace()?null:e(r,n)},blankLine:function(r){r.cur=c},startState:function(){return{cur:i}}};export{a as http};
//# sourceMappingURL=http-Co793Lk8.js.map
