import{_ as o,d}from"./NewEditor-J5bBywjE.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c77f9fcc-6bad-400f-aab8-e3035507340d",e._sentryDebugIdIdentifier="sentry-dbid-c77f9fcc-6bad-400f-aab8-e3035507340d")}catch{}})();var f=o((e,n)=>{let t;return n==="sandbox"&&(t=d("#i"+e)),(n==="sandbox"?d(t.nodes()[0].contentDocument.body):d("body")).select(`[id="${e}"]`)},"getDiagramElement");export{f as g};
//# sourceMappingURL=chunk-55IACEB6-CARgzGYk.js.map
